@@ -56,8 +56,6 @@ class Reporter(object):
     def generate_html_report(self, output_folder, passed_cases, failed_cases, error_cases, start_time, platform_info,
                              auto_refresh):
         with open(output_folder + os.sep + "report.html", "w") as report_file_handler:
-            back_ground_color_page = "#FFFFFF"
-            bg_color_column = "#ADADAD"
             end_time = datetime.datetime.now()
             execution_time = end_time - start_time
             execution_time = convert_to_seconds(execution_time)
@@ -179,9 +177,9 @@ class Reporter(object):
                 function copyFailedTestCase(){
                     document.getElementById("failed_testcase_names").style.display="none";
                     if (%s === 1){
-                        document.getElementById("copy_status_info").innerHTML = "<font color=darkgoldenrod>Copied 1 TestCase</font>";
+                        document.getElementById("copy_status_info").innerHTML = "<font style='padding-left: 56' color=darkorange>Copied 1 TestCase</font>";
                     } else if(%s > 1){
-                        document.getElementById("copy_status_info").innerHTML = "<font color=darkgoldenrod>Copied %s TestCases</font>";
+                        document.getElementById("copy_status_info").innerHTML = "<font style='padding-left: 56' color=darkorange>Copied %s TestCases</font>";
                     }
                     setTimeout(function(){
                         document.getElementById("copy_status_info").innerHTML = "";
@@ -201,8 +199,11 @@ class Reporter(object):
                     %s
                     %s
                 </head>
+                <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-gH2yIJqKdNHPEq0n4Mqa/HGKIhSkIHeL5AyhkYV8i59U5AR6csBvApHHNl/vI1Bx" crossorigin="anonymous">
+                <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.2.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-A3rJD856KowSb7dwlZdYEkO39Gagi7vIsF0jrRAoQmDKKtQBHUuLZ9AsSv4jD4Xa" crossorigin="anonymous"></script>
                 <script type="text/javascript" src="https://cdn.jsdelivr.net/clipboard.js/1.5.12/clipboard.min.js"></script>
                 <script type="text/javascript" src="https://cdn.jsdelivr.net/npm/echarts@5.0.2/dist/echarts.min.js"></script>
+                
             """ % (
                 css,
                 java_script_code_for_filter,
@@ -214,93 +215,55 @@ class Reporter(object):
             environment = settings.ENVIRONMENT
 
             str_top_table = """
-            <body  bgcolor='%s'>
-            <table align='center' cellpadding=0 cellspacing=0 style='border-collapse: collapse' width='925'>
+            <body>
+            <table align='center'>
                 <tr>
                     <td>
-                        <div id='chart_div' style="min-width: 500px; height: 300px; margin: 0 auto"></div>
+                        <div id='chart_div' style="min-width: 560px; height: 330px; migin: 10 auto"></div>
                     </td>
                     <td>
-                        <table border='1' align='center' cellpadding=3 cellspacing=3 style='border-collapse: collapse' width='425'>
-                            <tr style='font-size: 18'  bgcolor='%s'>
-                                <td>
-                                    <font color='#2850A5'>&nbsp; Report Generation Time</font>
-                                </td>
-                                <td width='180' align='center'>
-                                    <font color='#2850A5'>%s</font>
-                                </td>
+                        <table border='0' class="table table-hover">
+                            <tr style='background-color: whitesmoke;'>
+                                <th>Execution Start Time</th>
+                                <td align="center">%s</td>
                             </tr>
                             <tr>
-                                <td>
-                                    <font color='#2850A5'> &nbsp; Total Execution Duration</font>
-                                </td>
-                                <td width='150' align='center'><font color='#2850A5'>%s (Seconds)</font>
-                                </td>
+                                <th>Execution Duration</th>
+                                <td align='center'>%s (Seconds)</td>
                             </tr>
                             <tr>
-                                <td>
-                                    <font color='#2850A5'>  &nbsp; Total Test Cases</font>
-                                </td>
-                                <td align='center' width='150'>
-                                    <font color='#2850A5'>%s</font>
-                                </td>
+                                <th>Total TestCases</th>
+                                <td align='center'>%s</td>
                             </tr>
                             <tr>
-                                <td>
-                                    <font color='#2850A5'>  &nbsp; Passed</font>
-                                </td>
-                                <td align='center'>
-                                    <font color='#2850A5'>%s</font>
-                                </td>
+                                <th>Passed</th>
+                                <td align='center'>%s</td>
                             </tr>
                             <tr>
-                                <td>
-                                    <font color='#2850A5'>  &nbsp; Failed</font>
-                                </td>
-                                <td align='center'>
-                                    <font color='#2850A5'>%s</font>
-                                </td>
+                                <th>Failed</th>
+                                <td align='center'>%s</td>
                             </tr>
                             <tr>
-                                <td>
-                                    <font color='#2850A5'>  &nbsp; Environment</font>
-                                </td>
-                                <td align='center'>
-                                    <font color='#2850A5'>%s</font>
-                                </td>
+                                <th>Environment</th>
+                                <td align='center'>%s</td>
                             </tr>
                             <tr>
-                                <td>
-                                    <font color='#2850A5'>  &nbsp; Threads Count</font>
-                                </td>
-                                <td align='center'>
-                                    <font color='#2850A5'>%s</font>
-                                </td>
+                                <th>Thread Count</th>
+                                <td align='center'>%s</td>
                             </tr>
                             <tr>
-                                <td>
-                                    <font color='#2850A5'>  &nbsp; Execution Host</font>
-                                </td>
-                                <td align='center'>
-                                    <font color='#2850A5'>%s</font>
-                                </td>
+                                <th>Execution Host</th>
+                                <td align='center'>%s</td>
                             </tr>
                             <tr>
-                                <td>
-                                    <font color='#2850A5'> &nbsp; Test Framework</font>
-                                </td>
-                                <td align='center'>
-                                    <font color='#2850A5'>lintest==%s</font>
-                                </td>
+                                <th>Test Framework</th>
+                                <td align='center'>lintest==%s</td>
                             </tr>
                         </table>
                     </td>
                 </tr>
             </table>
-            <br>
             """ % (
-                back_ground_color_page,
-                bg_color_column,
                 datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S %p"),
                 execution_time,
                 len(passed_cases) + failed_cases_count,
@@ -329,9 +292,10 @@ class Reporter(object):
 
             # generate the drop down list for all the different tags
             html_drop_down_list = """
-            <table border='0' align='center' cellpadding=0 cellspacing=0 style='border-collapse: collapse' width='925'>
+            <br>
+            <table border='0' align='center' width='920'>
                 <tr>
-                    <td width='200'>Filter Test Cases By Package: </td>
+                    <td width='265'><font style='color: black; font-size: 18'>Filter TestCases By Package: </font></td>
                     <td>
             """
             report_file_handler.write(html_drop_down_list)
@@ -356,11 +320,9 @@ class Reporter(object):
                     str_failed_testcase_names += failed_testcase.__class__.__name__ + " "
 
                 str_failed_testcases = """
-                <div align="center" color="darkgoldenrod">
-                    <button id="failed_testcase_names" class='failed_testcase_names' data-clipboard-text="%s" onclick="copyFailedTestCase()">
-                        <font color='darkgoldenrod'>Click to Copy the Failed TestCase Names!</font>
-                    </button>
-                </div>
+                <button style='background-color: darkorange; border-radius: 10px;' id="failed_testcase_names" data-clipboard-text="%s" onclick="copyFailedTestCase()">
+                    <font color='white'>Copy Failed Case Names</font>
+                </button>
                 <script>
                     new Clipboard('.failed_testcase_names');
                 </script>
@@ -373,26 +335,21 @@ class Reporter(object):
 
             if len(failed_cases) > 0:
                 failed_testcase_table = """
-                <table border='1' align='center' cellpadding=3 cellspacing=3 style='border-collapse: collapse' width='925'>
-                    <tr id='all_failed_test_cases' bgcolor='%s' width='925'>
-                        <td width='125' align='center'>
-                            <b>
-                                <font color='#A52812'>TestCaseID</font>
-                            </b>
-                        </td>
-                        <td width='650' style='word-break:break-all' align='center'>
-                            <b>
-                                <font id='num_fail' color='#A52812'>%s Test %s Failed</font>
-                            </b>
-                        </td>
-                        <td width='150' align='center'>
-                            <b>
-                                <font color='#A52812'>Execution Duration(Seconds)</font>
-                            </b>
-                        </td>
+                <table align='center'>
+                <tr><td>
+                <table class='table table-hover' border='0'>
+                    <tr id='all_failed_test_cases' style='color:#DC3912; background-color: whitesmoke;'>
+                        <th width='120'>
+                               TestCaseID
+                        </th>
+                        <th width='710'>
+                                <font id='num_fail'>%s Test%s Failed</font>
+                        </th>
+                        <th width='200'>
+                            Duration(Seconds)
+                        </th>
                     </tr>
                 """ % (
-                    bg_color_column,
                     failed_cases_count,
                     "Cases" if failed_cases_count > 1 else "Case"
                 )
@@ -419,12 +376,12 @@ class Reporter(object):
                     module_name_display = failed_testcase.__module__.replace("tests.", "&#x0009;")
                     module_name_display += os.sep + failed_testcase.__class__.__name__
                     report_file_handler.write(
-                        "<tr class='all_failed_case' name=%s  width='925'>" % failed_testcase.testcase_filter_tag)
+                        "<tr class='all_failed_case' name=%s>" % failed_testcase.testcase_filter_tag)
 
                     report_file_handler.write(
                         "<td width='125' align='center' style='word-break:break-all;no-wrap:no-wrap'>")
                     report_file_handler.write(
-                        "<a title='Click to go to test center' href='https://testcenter.lintest.com/testlink/linkto.php?tprojectPrefix=ET&item=testcase&id=ET-%s'><font color='#A52812'>" % getattr(
+                        "<a title='Click to go to test center' href='https://testcenter.lintest.com/testlink/linkto.php?tprojectPrefix=ET&item=testcase&id=ET-%s'><font color='#DC3912'>" % getattr(
                             failed_testcase, "testcase_id", "None"))
                     report_file_handler.write("%s" % getattr(failed_testcase, "testcase_id", "None"))
                     report_file_handler.write("</font></a>")
@@ -433,7 +390,7 @@ class Reporter(object):
                     testcase_information = """
                         <td width='650'style='word-break:break-all'>
                         <a  href='%s'>
-                            <font color='#2850A5'>
+                            <font color='#333'>
                                 %s
                             </font>
                         </a>
@@ -453,7 +410,7 @@ class Reporter(object):
                     if failed_testcase.rerun_tag == 0:
                         try:
                             report_file_handler.write(
-                                "<a title='Log' href='%s'>        <font color='#F18428'>   Log</font> </a>" %
+                                "<a title='Click to see the log detail' href='%s'><font style='color: red'> Log</font></a>" %
                                 failed_testcase.log_file_path)
                         except BaseException:
                             print(traceback.format_exc())
@@ -461,7 +418,7 @@ class Reporter(object):
                         try:
                             if isinstance(failed_testcase, UITestCase):
                                 report_file_handler.write(
-                                    "<a title='Screenshot' href='%s'> <font color='#F18428'> - Screenshot</font> </a>" %
+                                    "<a title='Screenshot' href='%s'> <font color='#DC3912'> - Screenshot</font> </a>" %
                                     failed_testcase.screenshot)
                         except BaseException:
                             print(traceback.format_exc())
@@ -469,7 +426,7 @@ class Reporter(object):
                     elif failed_testcase.rerun_tag == 1:
                         try:
                             report_file_handler.write(
-                                "<a title='ReRun_Log' href='%s'> <font color='#F18428'> | ReRun_Log</font> </a>" %
+                                "<a title='ReRun_Log' href='%s'> <font color='#DC3912'> | ReRun_Log</font> </a>" %
                                 failed_testcase.log_file_path)
                         except BaseException:
                             print(traceback.format_exc())
@@ -477,7 +434,7 @@ class Reporter(object):
                         try:
                             if isinstance(failed_testcase, UITestCase):
                                 report_file_handler.write(
-                                    "<a title='ReRun_Screenshot' href='%s'> <font color='#F18428'> - ReRun_Screenshot</font> </a>" %
+                                    "<a title='ReRun_Screenshot' href='%s'> <font color='#DC3912'> - ReRun_Screenshot</font> </a>" %
                                     failed_testcase.rerun_screenshot)
                         except BaseException:
                             print(traceback.format_exc())
@@ -485,37 +442,33 @@ class Reporter(object):
                     report_file_handler.write("</td>")
 
                     report_file_handler.write("<td width='150' align='center' >")
-                    report_file_handler.write("<font color='#A52812'>")
+                    report_file_handler.write("<font>")
                     if not hasattr(failed_testcase, "execution_time"):
                         failed_testcase.execution_time = ""
                     report_file_handler.write("%s" % failed_testcase.execution_time)
                     report_file_handler.write("</font>")
                     report_file_handler.write("</td></tr>")
-                report_file_handler.write("</table>")
-            report_file_handler.write("<br>")
+                report_file_handler.write("</table></td></tr></table>")
+            # report_file_handler.write("<br>")
 
             if len(passed_cases) > 0:
                 passed_testcase_table = """
-                <table border='1' align='center' cellpadding=3 cellspacing=3 style='border-collapse: collapse' width='925'>
-                    <tr id='all_passed_test_cases' bgcolor='%s' width='925'>
-                        <td width='125' align='center'>
-                            <b>
-                                <font color='#2850A5'>TestCaseID</font>
-                            </b>
-                        </td>
-                        <td width='650' style='word-break:break-all' align='center'>
-                            <b>
-                                <font id='num_pass' color='#2850A5'>%s  Test %s Passed</font>
-                            </b>
-                        </td>
-                        <td width='150' align='center'>
-                            <b>
-                                <font color='#2850A5'>Execution Duration(Seconds)</font>
-                            </b>
-                        </td>
+                <table align='center'>
+                <tr><td>
+
+                <table class='table table-hover' border='0'>
+                    <tr id='all_passed_test_cases' style='color:#3366CC; background-color: whitesmoke;'>
+                        <th width='120'>
+                            TestCaseID
+                        </th>
+                        <th width='710'>
+                                <font id='num_pass'>%s  Test%s Passed</font>
+                        </th>
+                        <th width='200'>
+                                Duration(Seconds)
+                        </th>
                     </tr>
                 """ % (
-                    bg_color_column,
                     len(passed_cases),
                     "Cases" if len(passed_cases) > 1 else "Case"
                 )
@@ -527,13 +480,13 @@ class Reporter(object):
                     module_name_display += os.sep + passed_testcase.__class__.__name__
 
                     report_file_handler.write(
-                        "<tr class='all_passed_case' name=%s  width='925'>" % getattr(passed_testcase,
+                        "<tr class='all_passed_case' name=%s>" % getattr(passed_testcase,
                                                                                       "testcase_filter_tag",
                                                                                       "None"))
 
                     report_file_handler.write("<td width='125' align='center' >")
                     report_file_handler.write(
-                        "<a title='Click to go to test center' href='https://testcenter.lintest.com/testlink/linkto.php?tprojectPrefix=ET&item=testcase&id=ET-%s'> <font color='#2850A5'>" % getattr(
+                        "<a title='Click to go to test center' href='https://testcenter.lintest.com/testlink/linkto.php?tprojectPrefix=ET&item=testcase&id=ET-%s'> <font color='#333'>" % getattr(
                             passed_testcase, "testcase_id", "None"))
                     report_file_handler.write("%s" % getattr(passed_testcase, "testcase_id", "None"))
                     report_file_handler.write("</font></a>")
@@ -544,7 +497,7 @@ class Reporter(object):
                     report_file_handler.write(module_name)
                     report_file_handler.write(
                         "'><font color='%s'>" % (
-                            "#2850A5" if passed_testcase.rerun_tag == 0 else "green"))
+                            "#333" if passed_testcase.rerun_tag == 0 else "green"))
                     report_file_handler.write(module_name_display)
 
                     # show re-run got passed in report
@@ -559,7 +512,7 @@ class Reporter(object):
 
                     try:
                         report_file_handler.write(
-                            "<a title='Log' href='%s'>        <font color='green'>&nbsp;&nbsp;Log</font> </a>" %
+                            "<a title='Click to show log detail' href='%s'>        <font color='green'>&nbsp;&nbsp;Log</font> </a>" %
                             passed_testcase.log_file_path)
                     except BaseException:
                         print(traceback.format_exc())
@@ -593,7 +546,7 @@ class Reporter(object):
                     report_file_handler.write("</td>")
 
                     report_file_handler.write("<td width='150' align='center'>")
-                    report_file_handler.write("<font color='#2850A5'>")
+                    report_file_handler.write("<font color='#333'>")
 
                     if not hasattr(passed_testcase, "execution_time"):
                         passed_testcase.execution_time = ""
@@ -601,7 +554,7 @@ class Reporter(object):
                     report_file_handler.write("%s" % passed_testcase.execution_time)
                     report_file_handler.write("</font>")
                     report_file_handler.write("</td></tr>")
-                report_file_handler.write("</table>")
+                report_file_handler.write("</table></td></tr></table>")
 
             report_file_handler.write("<br><br>")
 
@@ -667,7 +620,10 @@ class Reporter(object):
 
                     option && myChart.setOption(option);
             </script>
+                            
+            <script>$(function () { $("[data-toggle='tooltip']").tooltip(); });</script>
+            
                    """ % (len(passed_cases), failed_cases_count)
 
             report_file_handler.write(echarts_str)
-            report_file_handler.write("</body></html>")
+            report_file_handler.write("</div></body></html>")
